@@ -501,8 +501,8 @@ prettyDate_TMP <-
              "1 DSTday" = list(1*DAY, format = "%b %d"),
              "2 DSTdays" = list(2*DAY),
              "1 week" = list(7*DAY, start = "weeks"),
-             "2 weeks" = list(14*DAY),
-             "1 month" = list(1*MONTH, format = "%Y %b"),
+             "2 weeks" = list(15*DAY, start = "months"),
+             "1 month" = list(1*MONTH, format = "%b"),
              "3 months" = list(3*MONTH, start = "years"),
              "6 months" = list(6*MONTH, format = "%Y-%m"),
              "1 year" = list(1*YEAR, format = "%Y"),
@@ -548,7 +548,7 @@ prettyDate_TMP <-
     makeOutput <- function(at, s) {
         flabels <- format(at, s$format)
         ans <-
-            if (isDate) round(as.Date(at))
+            if (isDate) as.Date(round(at, "days"))
             else as.POSIXct(at)
         attr(ans, "labels") <- flabels
         ans
