@@ -110,7 +110,7 @@ diag.panel.splom <-
             panel.axis(side = side,
                        at = at,
                        labels = lab,
-                       tick = TRUE,
+                       ticks = TRUE,
                        half = TRUE,
 
                        tck = axis.line.tck,
@@ -350,11 +350,12 @@ splom.data.frame <-
     ccall <- match.call()
     if (!is.null(ccall$data)) 
         warning("explicit 'data' specification ignored")
-    ccall$data <-
-        list(x = x, groups = groups, subset = subset)
     ccall$x <- ~x
-    ccall$groups <- groups
-    ccall$subset <- subset
+    ccall$data <- environment()
+    ## WAS:
+    ## ccall$data <- list(x = x, groups = groups, subset = subset)
+    ## ccall$groups <- groups
+    ## ccall$subset <- subset
     ccall[[1]] <- quote(lattice::splom)
     eval.parent(ccall)
 }
@@ -551,8 +552,7 @@ splom.formula <-
           cond.orders(foo))
     foo[names(more.comp)] <- more.comp
 
-    if (is.null(foo$legend) && !is.null(groups) &&
-        (is.list(auto.key) || (is.logical(auto.key) && auto.key)))
+    if (is.null(foo$legend) && needAutoKey(auto.key, groups))
     {
         foo$legend <-
             list(list(fun = "drawSimpleKey",
